@@ -5,10 +5,9 @@
 """
 Taiga Python API library
 """
-__version__ = '0.8.5'
+__version__ = '0.9.0'
 __author__ = 'Nephila'
 __license__ = 'MIT'
+__all__ = ['TaigaAPI']
 
 from .client import TaigaAPI
-
-__all__ = ["TaigaAPI"]
